``dms_variants`` documentation
===================================================

``dms_variants`` is a Python package written by `the Bloom lab <https://research.fhcrc.org/bloom/en.html>`_.
It can be used to analyze deep mutational scanning of libraries of barcoded variants, and fit global epistasis models.

See below for information and examples of how to use this package.

Contents
----------
.. toctree::
   :hidden:

   self

.. toctree::
   :maxdepth: 2

   installation
   examples
   dms_variants
   package_index
   acknowledgments
